// interface definition for IConfigLine
//
// Copyright Matthias Gaertner, Schenefeld, Germany, 2001
// You may use this code under the terms of the GPL.
// Updated packages may be found at http://www.rtner.de/parsled/
//
//
// This class abstracts a configuration line of the form
//   Token[=[Data]]

#ifndef __ICONFIG_LINE_H
#define __ICONFIG_LINE_H

#include <SimpleString.h>
#include <IConfigurationSource.h>

class IConfigLine
{
public:
    virtual ~IConfigLine() = 0;

    virtual void feed( IConfigurationSource * ) = 0;

    virtual bool isComment() const = 0;
    virtual const SimpleString &getToken() const = 0;
    virtual const SimpleString &getData() const = 0;
    virtual bool hasData() const = 0;
    virtual bool isSection() const = 0;

    // Implementation helpers
    int scanYesNo( const char *token, bool *p );                    // Yes/No
    int scanPositiveInt( const char *token, unsigned int *p );      // >  1
    int scanNonNegativeInt( const char *token, unsigned int *p );   // >= 1
    int scanNonEmptyString( const char *token, SimpleString *p );   // anything, but not empty
};

#endif /* __ICONFIG_LINE_H */

/* */
